# Django Silly Stripe

DSS focuses only on making SAAS subscriptions as simple as possible.

It is based on stripe's python API.



### [Read the wiki to install and use DSS in your application](https://github.com/byoso/django-silly-stripe/wiki)
